#
# spec file for package kxmlgui
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define lname   libKF5XmlGui5
# Full KF5 version (e.g. 5.33.0)
%{!?_kf5_version: %global _kf5_version %{version}}
# Last major and minor KF5 version (e.g. 5.33)
%{!?_kf5_bugfix_version: %define _kf5_bugfix_version %(echo %{_kf5_version} | awk -F. '{print $1"."$2}')}
%define qt5_version 5.15.2
%bcond_without released
Name:           kxmlgui
Version:        5.116.0
Release:        1.5
Summary:        Framework for managing menu and toolbar actions
License:        LGPL-2.1-or-later AND GPL-2.0-or-later
URL:            https://www.kde.org
Source:         %{name}-%{version}.tar.xz
%if %{with released}
Source1:        %{name}-%{version}.tar.xz.sig
Source2:        frameworks.keyring
%endif
BuildRequires:  extra-cmake-modules >= %{_kf5_version}
BuildRequires:  fdupes
BuildRequires:  cmake(KF5Config) >= %{_kf5_version}
BuildRequires:  cmake(KF5ConfigWidgets) >= %{_kf5_version}
BuildRequires:  cmake(KF5CoreAddons) >= %{_kf5_version}
BuildRequires:  cmake(KF5GlobalAccel) >= %{_kf5_version}
BuildRequires:  cmake(KF5GuiAddons) >= %{_kf5_version}
BuildRequires:  cmake(KF5I18n) >= %{_kf5_version}
BuildRequires:  cmake(KF5IconThemes) >= %{_kf5_version}
BuildRequires:  cmake(KF5ItemViews) >= %{_kf5_version}
BuildRequires:  cmake(KF5WidgetsAddons) >= %{_kf5_version}
# Now requires private headers
BuildRequires:  libqt5-qtbase-private-headers-devel >= %{qt5_version}
BuildRequires:  pkgconfig
BuildRequires:  cmake(Qt5Core) >= %{qt5_version}
BuildRequires:  cmake(Qt5DBus) >= %{qt5_version}
BuildRequires:  cmake(Qt5Network) >= %{qt5_version}
BuildRequires:  cmake(Qt5PrintSupport) >= %{qt5_version}
BuildRequires:  cmake(Qt5Test) >= %{qt5_version}
BuildRequires:  cmake(Qt5UiPlugin) >= %{qt5_version}
BuildRequires:  cmake(Qt5Widgets) >= %{qt5_version}
BuildRequires:  cmake(Qt5Xml) >= %{qt5_version}
BuildRequires:  pkgconfig(x11)

%description
libkxmlgui provides a framework for managing menu and toolbar actions in an
abstract way. The actions are configured through a XML description and hooks
in the application code. The framework supports merging of multiple
description for example for integrating actions from plugins.

%package -n %{lname}
Summary:        Framework for managing menu and toolbar actions
Obsoletes:      libKF5XmlGui4

%description -n %{lname}
libkxmlgui provides a framework for managing menu and toolbar actions in an
abstract way. The actions are configured through a XML description and hooks
in the application code. The framework supports merging of multiple
description for example for integrating actions from plugins.

%package devel
Summary:        Framework for managing menu and toolbar actions
Requires:       %{lname} = %{version}
Requires:       cmake(KF5Config) >= %{_kf5_version}
Requires:       cmake(KF5ConfigWidgets) >= %{_kf5_version}
Requires:       cmake(Qt5DBus) >= %{qt5_version}
Requires:       cmake(Qt5Widgets) >= %{qt5_version}
Requires:       cmake(Qt5Xml) >= %{qt5_version}

%description devel
libkxmlgui provides a framework for managing menu and toolbar actions in an
abstract way. The actions are configured through a XML description and hooks
in the application code. The framework supports merging of multiple
description for example for integrating actions from plugins. Development files.

%lang_package -n %{lname}

%prep
%autosetup -p1

%build
%cmake_kf5 -d build -- -DSYSCONF_INSTALL_DIR=%{_kf5_sysconfdir}
%cmake_build

%install
%kf5_makeinstall -C build
%fdupes %{buildroot}

mkdir -p %{buildroot}%{_kf5_sharedir}/kxmlgui5/

%find_lang kxmlgui5

%ldconfig_scriptlets -n %{lname}

%files -n %{lname}-lang -f kxmlgui5.lang

%files -n %{lname}
%license LICENSES/*
%doc README*
%{_kf5_libdir}/libKF5XmlGui.so.*
%{_kf5_configdir}/ui/
%{_kf5_libexecdir}/ksendbugmail
%dir %{_kf5_sharedir}/kxmlgui5/
%{_kf5_debugdir}/kxmlgui.categories
%{_kf5_debugdir}/*.renamecategories

%files devel
%{_kf5_libdir}/libKF5XmlGui.so
%{_kf5_libdir}/cmake/KF5XmlGui/
%{_kf5_includedir}/KXmlGui/
%{_kf5_mkspecsdir}/qt_KXmlGui.pri
%dir %{_kf5_plugindir}/designer
%{_kf5_plugindir}/designer/kxmlgui5widgets.so

%changelog
* Mon May  6 2024 Christophe Marin <christophe@krop.fr>
- Update to 5.116.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.116.0
- No code change since 5.115.0
* Thu Feb  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 5.115.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.115.0
- No code change since 5.114.0
* Sat Jan 13 2024 Christophe Marin <christophe@krop.fr>
- Update to 5.114.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.114.0
- No code change since 5.113.0
* Tue Dec  5 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.113.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.113.0
- No code change since 5.112.0
* Mon Nov  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.112.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.112.0
- No code change since 5.111.0
* Mon Oct  9 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.111.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.111.0
- No code change since 5.110.0
* Wed Sep  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.110.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.110.0
- No code change since 5.109.0
* Tue Aug  8 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.109.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.109.0
- Changes since 5.108.0:
  * Add explicit moc includes to sources for moc-covered headers
* Mon Jul  3 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.108.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.108.0
- Changes since 5.107.0:
  * Remove qt6 CI builds
  * Add a view_redisplay_merge MergeLocal to ui_standards.rc (kde#470848)
* Mon Jun  5 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.107.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.107.0
- No code change since 5.106.0
* Sat May  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.106.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.106.0
- Changes since 5.105.0:
  * Take two: Cherry-pick KMainWindow documentation fixes to KF5
  * Take two: Cherry-pick KXmlGuiWindow documentation fixes to KF5
  * kcheckaccelerators: Don't blindly cast to QWidget (kde#468576)
  * Fix Qt 6.5 compatibility
* Sat Apr  1 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.105.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.105.0
- No code change since 5.104.0
* Mon Mar  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.104.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.104.0
- Changes since 5.103.0:
  * Fix testAutoSaveSettings
* Wed Feb  8 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.103.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.103.0
- Changes since 5.102.0:
  * Prevent user from expanding tooltips by key, if they weren't expandable
  * Remove duplicate "Whats This?" tooltips
* Thu Jan 12 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.102.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.102.0
- Changes since 5.101.0:
  * Decrease minimum height of inactive list widget (kde#461580)
* Tue Dec  6 2022 Christophe Marin <christophe@krop.fr>
- Update to 5.101.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.101.0
- Changes since 5.100.0:
  * Better/corrected wording as suggested by Felix Ernst
  * Added a doc note how to get a menu's action
  * Perform initialization in initialization list
* Tue Nov  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.100.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.100.0
- Changes since 5.99.0:
  * Add Qt6 windows CI support
* Sat Oct  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.99.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.99.0
- Changes since 5.98.0:
  * use same config for position restoration as for position saving
* Tue Sep  6 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.98.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.98.0
- Changes since 5.97.0:
  * Fix crash in addActionToSchemesMoreButton() introduced by merge mistake
  * Add FreeBSD Qt6 CI support
* Sun Aug  7 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.97.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.97.0
- Changes since 5.96.0:
  * [KShortcutsDialog] Make it possible to reload shortcut schemes
  * [KShortcutsDialog] Make it possible to add a custom edit action
  * [KShortcutSchemesEditor] Fix bug introduced by refactoring in commit de0790fe
  * Fix crash of KMix in Legacy Tray
  * [KShortcutsDialog] Add icons for actions
  * KKeySequenceWidget: don't use a QHash to hold a few elements
* Sun Jul  3 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.96.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.96.0
- Changes since 5.95.0:
  * Fix QWhatsThis links not being clickable
  * Allow to load rc file in kf6
  * Fix typo in local variable name
* Fri Jun 10 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.95.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.95.0
- Changes since 5.94.0:
  * KShortcutsDialog: hide Global columns when there are no Global shortcuts (kde#427129)
  * Silence UBSan false positive in KActionCollection
  * port to standard C++ smart pointers where possible
* Tue May 10 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.94.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.94.0
- Changes since 5.93.0:
  * autotests: skip kde-global settings changes on Windows (no DBus)
  * ui_standards.rc: add tag so kate can insert a menu between Edit and View
  * Add autotests for autosaving in combination with separate state config
  * Fix saving of state config if one has autosave enabled (kde#451725)
  * Add windows CI
  * Port away from QObject::sender()
  * KToolBar: code refactoring
  * Replace OS-specific system information code with QSysInfo (kde#450862)
* Sun Apr  3 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.93.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.93.0
- Changes since 5.92.0:
  * Require unittests to pass for CI jobs to pass
  * KShortcutsEditorDelegate: Fix HiDPI rendering of indicator arrows (kde#414904)
  * Tests: Enable HiDPI pixmap rendering
  * Add Android to supported platforms in repo metadata
  * Fix broken "Add to Toolbar" action
* Mon Mar  7 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.92.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.92.0
- Changes since 5.91.0:
  * Remove outdated readme file
  * Add Qt6 Android CI
  * Add an old formatting commit to git blame ignore file
  * Make the BUILD_DESIGNERPLUGIN option dependent on not cross-compiling
  * Support build without Qt session manager
  * Add an action in help menu for command bar
  * Update translation context of two strings
* Sun Feb  6 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.91.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.91.0
- Changes since 5.90.0:
  * Check executables exist in PATH before passing them to QProcess
  * Use uppercase includes
  * Allow KToolBar to be in other places than MainWindow's ToolBarArea
  * Fix i18n comment not being properly extracted
  * Add CI qt6 support
* Mon Jan  3 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.90.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.90.0
- Changes since 5.89.0:
  * Port deprecated method
  * Fix nested @ expansion in CMake config file
  * [KToolBar] Add actions from delayed toolbutton menus to context menu
  * Change the build system to enable building with Qt6
  * Do not steal all keys from shortcut
* Sat Dec  4 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.89.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.89.0
- No code change since 5.88.0
* Sun Nov  7 2021 Christophe Giboudeaux <christophe@krop.fr>
- Strip 'Source' URL for faster submissions
* Sun Nov  7 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.88.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.88.0
- Changes since 5.87.0:
  * Remove duplicate includes from .cpp/.h
  * Add unit test for storing window state State separately
  * Migrate "State" config entry to state config group if available
  * Allow apps to opt-in storing state data in separate file
  * Add FreeBSD CI
  * Add Android CI
  * [ci] Remove unused kwindowsystem dep
  * Fix CI deps
* Sun Oct  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.87.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.87.0
- Changes since 5.86.0:
  * Add Gitlab CI configuration
  * Add missing Q_INIT_RESOURCE(kxmlgui)
  * Replace "Libraries" by "Components" to show KAboutComponents info
* Wed Sep 15 2021 Christophe Giboudeaux <christophe@krop.fr>
- Drop the unneeded baselibs.conf.
* Mon Sep  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.86.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.86.0
- Changes since 5.85.0:
  * Qt5CorePrivate is not a thing
  * Add support for static builds
  * We depend against c++-17 so we can use qOverload directly
  * replace "MacOSX" with "macOS"
  * In qt6 signature was changed (ported by script)
* Fri Aug  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.85.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.85.0
- Changes since 5.84.0:
  * commandbar: collect actions using the guiFactory (kde#439526)
  * Fix KShortcutsDialog build
  * KShortcutsDialog: add another, simpler, constructor
* Sun Jul  4 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.84.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.84.0
- Too many changes since 5.83.0, only listing bugfixes:
  * Hide tooltip instantly before showing whatsthis (kde#438580)
* Wed Jun 30 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Drop 0001-Revert-Fix-initial-window-size-calculations.patch,
  issue with konsole got fixed (kde#437791)
* Sat Jun  5 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.83.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.83.0
- Changes since 5.82.0:
  * Add KCommandBar to KXMLGui-using apps by default
  * Remove the Attica requirement by using the store's new links
  * Bump required CMake version to 3.16
  * Use new version-controlled enumerator deprecation warning macros
  * Ensure instances of derived Private classes are properly destructed
  * Don't translate urls (kde#436052)
  * Call ki18n_install() unconditionally
* Sun May  9 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Add patch to fix initial window size of konsole:
  * 0001-Revert-Fix-initial-window-size-calculations.patch
* Sat May  1 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.82.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.82.0
- Changes since 5.81.0:
  * Fix initial window size calculations
  * Fix mem leak found by asan
  * Don't forward declaration when we already include files
  * Remove unused include
  * kxmlgui_unittest: Do not fail if LC_ALL ENV variable is set
  * Fix autotest build without D-Bus on Android
  * Add .git-blame-ignore-revs file
  * Don't build with KGlobalAccel on Windows, Mac, and Android
* Mon Apr  5 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.81.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.81.0
- Changes since 5.80.0:
  * Tweaks
  * Run clang-format
  * Prevent clang-format uglification
  * Add clang-format pre-commit hook
  * Add trailing comma to enums
* Sun Mar  7 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.80.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.80.0
- Changes since 5.79.0:
  * Add an autotest for the newly added call
  * Add a missing addAction new-slot-syntax call
  * Correct name of menu item (kde#433157)
* Mon Feb  8 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.79.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.79.0
- Changes since 5.78.0:
  * Fix includes
  * Add KXMLGUIFactory::shortcutsSaved signal
  * Use the correct kde get involved url (kde#430796)
* Wed Jan  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.78.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.78.0
- Changes since 5.77.0:
  * KXmlGui: when upgrading a local .rc file, keep new app toolbars
  * Fix key recording by setWindow before capture starts. (kde#430388)
  * Remove ifdefs, we require Qt 5.14 now
  * operator+/- is disabled for QFlags in qt6
  * Remove unused KWindowSystem dependency
  * Clear KXMLGUIClient in memory xml doc after saving shortcuts to disk
* Mon Dec  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.77.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.77.0
- Changes since 5.76.0:
  * Pass parent to Q*Layout ctor instead of calling setLayout()
  * autotests: fix for Windows by using GenericDataLocation
  * We depend on Qt 5.13 now so we can remove this check
  * Introduce HideLibraries and deprecate HideKdeVersion
  * Fix build without KGlobalAccel
  * Rewrite KKeySequenceWidget to use KeySequenceRecorder
* Sat Nov  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.76.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.76.0
- Changes since 5.75.0:
  * If include is define in .h remove it if it's defined in .cpp too (scripted)
  * Add a KF6 TODO for KMainWindow::canBeRestored()
* Mon Oct  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.75.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.75.0
- Too many changes since 5.74.0, only listing bugfixes:
  * [kmainwindow] Don't delete entries from an invalid kconfiggroup (kde#427236)
  * Don't overlap main windows when opening additional instances (kde#426725)
  * [kmainwindow] Don't create native windows for non-toplevel windows (kde#424024)
  * Handle double close in main window (kde#416728)
* Sun Sep  6 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.74.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.74.0
- Changes since 5.73.0:
  * Using no deprecated enum Qt::MiddleButton
  * Allow opting out of remembering window positions on X11
  * Save and restore position of main window (kde#415150)
  * Remove obsolete COPYING files
  * KXMLGUI: Convert copyright statements to SPDX expressions
* Sun Aug  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.73.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.73.0
- Changes since 5.72.0:
  * Use KF-standardized Qt logging categories
  * Make KXmlGuiVersionHandler::findVersionNumber public in KXMLGUIClient
* Sun Jul  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.72.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.72.0
- Changes since 5.71.0:
  * Use kcm_users instead of user_manager
  * Use new KTitleWidget::icon/iconSize API
  * autotests: use ui_standards.rc from qrc from unittests
  * autotests: repair after previous commit, now the settings menu is always there
  * Move "Switch Application Language" to Settings menu (kde#177856)
* Sun Jun  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.71.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.71.0
- Changes since 5.70.0:
  * [KMainWindow] Invoke QIcon::setFallbackThemeName (later)
  * Fix build with EXCLUDE_DEPRECATED_BEFORE_AND_AT=CURRENT
* Sun May  3 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.70.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.70.0
- Changes since 5.69.0:
  * Improve warning
  * [KRichTextEditor] Add support for headings
  * [KKeySequenceWidget] Work around Meta modifier behavior
* Sun Apr  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.69.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.69.0
- Changes since 5.68.0:
  * Small speed improvement: test event type before doing qobject_cast
* Sun Mar  8 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.68.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.68.0.php
- Changes since 5.67.0:
  * Make it compile against q5.15. They reverted commit about error() vs networkerror()
  * Port QLinkedList which is deprecated in qt5.15
  * Port QProcess::start(...) deprecated method (qt5.15)
  * Use ecm_qt_install_logging_categories over manual categories file
* Sun Feb  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Replace %%make_jobs with %%cmake_build.
* Sun Feb  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.67.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.67.0.php
- Changes since 5.66.0:
  * autotests: mark known test failure with QEXPECT_FAIL
  * Use KStandardAction convenience method for switchApplicationLanguage
  * allow programLogo property to be a QIcon, too
  * Compile against qt5.15
  * remove ability to report bugs against arbitrary stuff from a static list
  * remove compiler information from bug report dialog
  * KMainWindow: fix autoSaveSettings to catch QDockWidgets being shown again
  * Drop unused headers
  * i18n: Add more semantic context strings
  * i18n: Split translations for strings "Translation"
* Sun Jan  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.66.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.66.0.php
- Changes since 5.65.0:
  * Remove endl. qCritical/qDebug already add a endl.
  * Port QSet::toList deprecated method
  * Update the obsolete projects.kde.org URL
  * KActionCollection: provide a changed() signal as a replacement for removed()
  * Adjust keyboard shortcut configuration window's title
* Sun Dec  8 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.65.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.65.0.php
- Changes since 5.64.0:
  * Unbreak last commit: still install normal headers as before
  * Drop unused broken KGesture support
  * Move comment to the right place
  * Port foreach
  * Port away from KTextWidgets
  * Add KAboutPluginDialog, to be used with KPluginMetaData
  * Enable -DKF_DISABLE_DEPRECATED_BEFORE_AND_AT=0x053f00
  * Also allow invoking session restoration logic when apps are manually launched
  * Add missing property to KKeySequenceWidget
* Sun Nov  3 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.64.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.64.0.php
- Changes since 5.63.0:
  * fix default shortcut detection
  * Use ECMGenerateExportHeader to manage deprecated API better
* Sun Oct  6 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.63.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.63.0.php
- Too many changes since 5.62.0, only listing bugfixes:
  * Move "Full Screen Mode" item from Settings menu to View menu (kde#106807)
* Sat Sep  7 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.62.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.62.0.php
- Changes since 5.61.0:
  * Add option to build Qt Designer plugin (BUILD_DESIGNERPLUGIN, default ON)
- Replace foo-devel with cmake(KF5Foo) in build requirements
* Wed Aug  7 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.61.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.61.0.php
- Changes since 5.60.0:
  * Add expanding spacers as a customization option for toolbars
  * Remove explicit use of ECM_KDE_MODULE_DIR, is part of ECM_MODULE_PATH
  * Use monochrome action icons for KAboutData buttons.
  * Remove visibilityChanged connection in favor of existing eventFilter
  * Remove unused includes
* Fri Jul 19 2019 Wolfgang Bauer <wbauer@tmo.at>
- Don't lower minimum Qt version anymore, it requires 5.11 now
- Drop conditionals for no longer supported openSUSE versions
* Sun Jul 14 2019 lbeltrame@kde.org
- Update to 5.60.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.60.0.php
- Changes since 5.59.0:
  * Install in new logging directory when we use kf5 5.59.0
* Sun Jun  9 2019 lbeltrame@kde.org
- Update to 5.59.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.59.0.php
- Changes since 5.58.0:
  * Remove deprecated method qVariantFromValue->QVariant::fromValue
* Wed May 15 2019 lbeltrame@kde.org
- Update to 5.58.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.58.0.php
- Changes since 5.57.0:
  * KKeySequenceWidget: Don't show English strings to the user
* Sun Apr 14 2019 lbeltrame@kde.org
- Update to 5.57.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.57.0.php
- No code changes since 5.56.0
* Sun Mar 10 2019 lbeltrame@kde.org
- Update to 5.56.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.56.0.php
- Changes since 5.55.0:
  * Windows: fix the fix for... etc. Can't use a switch here.
  * Fix the fix for Windows compilation
  * Fix compile on windows
  * [kxmlgui] remove deprecated method
  * Port deprecated methods
* Fri Feb 15 2019 alarrosa@suse.com
- Downgrade the Qt version requirement to build with 5.9
* Sun Feb 10 2019 lbeltrame@kde.org
- Update to 5.55.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.55.0.php
- Changes since 5.54.0:
  * Build without D-Bus on Android
  * delete copy constructor and assignment operator of some internal classes
  * Make KCheckAccelerators less invasive for apps that don't directly link to KXmlGui
* Mon Jan 14 2019 lbeltrame@kde.org
- Update to 5.54.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.54.0.php
- Changes since 5.53.0:
  * No code changes since 5.53.0
* Mon Dec 10 2018 wbauer@tmo.at
- Use gcc7 on Leap 42.3 to fix build, compilation fails with the
  default 4.8
* Sun Dec  9 2018 lbeltrame@kde.org
- Update to 5.53.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.53.0.php
- Changes since 5.52.0:
  * Use isEmpty()
  * Qt 5.9 is now the required version
  * Update the "About KDE" text
  * Mark member pointer const to tell it will not be changed by design
  * Use member-function-pointer-based signal/slot connection
  * krulertest: remove deprecated defunct call
* Sun Nov 11 2018 lbeltrame@kde.org
- Update to 5.52.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.52.0.php
- Changes since 5.51.0:
  * Remove unused variables
  * Take 1..n KMainWindows in kRestoreMainWindows
  * Remove "void" as function argument
  * Have include guard match header file name
  * Include own header first
  * Use single char for concat with QByteArray, not a string
  * Use more explicit constructors with internal classes
  * Use QStringLiteral if a final QString is wanted
  * Use value argument for QLatin1String type in internal API
  * Use more const ref with arguments in internal API
  * Add missing "emit"
  * Do not return void values in void methods
  * Use Q_OBJECT with all QObject subclasses (helps debugging introspection)
  * KAboutApplicationDialog: fix typo in apidox
  * Add categories file
  * Remove unused variable
* Tue Oct 16 2018 Luca Beltrame <lbeltrame@kde.org>
- Run spec-cleaner
* Mon Oct 15 2018 lbeltrame@kde.org
- Update to 5.51.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.51.0.php
- Changes since 5.50.0:
  * Remove unused variable
  * Fix compile with strict compiler flags
  * Fix OCS provider URL in about dialog
  * Fix remaining qWarning to be qCWarning
  * Remove Qt module prefix from includes
* Thu Sep 13 2018 lbeltrame@kde.org
- Update to 5.50.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.50.0.php
- Changes since 5.49.0:
  * Make Konqi look good in HiDPI
  * autotests: see if ru_RU works better than uk in CI.
  * Add missing parenthese
* Sun Aug 19 2018 christophe@krop.fr
- Update to 5.49.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.49.0.php
- Changes since 5.48.0:
  * Fix KMainWindow saving incorrect widget settings (kde#395988)
  * Honor BUILD_TESTING
* Mon Jul 16 2018 lbeltrame@kde.org
- Update to 5.48.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.48.0.php
- Changes since 5.47.0:
  * None
* Tue Jun 12 2018 lbeltrame@kde.org
- Update to 5.47.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.47.0.php
- Changes since 5.46.0:
  * None
* Sun May 13 2018 lbeltrame@kde.org
- Update to 5.46.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.46.0.php
- Changes since 5.45.0:
  * Use override
  * Warning--
* Sat Apr 14 2018 lbeltrame@kde.org
- Update to 5.45.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.45.0.php
- Changes since 5.44.0:
  * Remove not necessary QtCore and co
* Mon Mar 12 2018 lbeltrame@kde.org
- Update to 5.44.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.44.0.php
- Changes since 5.43.0:
  * Explicity include <QAction> to fix build with Qt 5.11
  * Fix build with Qt < 5.9
  * Reset QLocale internals when we have a custom app language
  * Do not allow to configure separator actions via context menu
  * Don't show context menu menu if right-clicking outside (kde#373653)
  * Improve KSwitchLanguageDialogPrivate::fillApplicationLanguages
* Mon Feb 12 2018 lbeltrame@kde.org
- Update to 5.43.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.43.0.php
- Changes since 5.42.0:
  * None
* Tue Jan 16 2018 lbeltrame@kde.org
- Update to 5.42.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.42.0.php
- Changes since 5.41.0:
  * Remove obsolete reviewboardrc file
  * KMainWindow_UnitTest: fix path used for wiping the config file
  * API dox: make doxygen cover session related macros & functions again
  * Disconnect shortcutedit slot on widget destruction (kde#387307)
* Sun Dec 17 2017 lbeltrame@kde.org
- Update to 5.41.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.41.0.php
- Changes since 5.40.0:
  * Compile with stricter compilation flags
  * Use qCDebug
  * Fix translation of toolbar name when it has i18n context
* Mon Nov 13 2017 lbeltrame@kde.org
- Update to 5.40.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.40.0.php
- Changes since 5.39.0:
  * I18n is always a QString
  * Use const'ref here
  * Use https for KDE urls
* Mon Oct 23 2017 lbeltrame@kde.org
- Update to 5.39.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.39.0.php
- Changes since 5.38.0:
  * Parallel autotests (step 2) : don't run ktoolbar_unittest in parallel with others
  * Parallel autotests (step 1) : use different filenames.
  * Remove horrendous eventFilter-on-paintEvent hack from KToolBar.
  * Fix KToolBar repaint loop BUG: 365050 BUG: 377859 Differential Revision: https://phabricator.kde.org/D7954 (kde#365050, kde#377859)
  * Drop KAction references from kxmlgui apidox
* Tue Sep 12 2017 lbeltrame@kde.org
- Update to 5.38.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.38.0.php
- Changes since 5.37.0:
  * Save up a bunch of stat() calls on application start
  * Fix KHelpMenu position on Wayland
  * Remove checks for Qt < 5.6, now that even 5.7 is required.
  * Do not leak symbols of pimpl classes, protect with Q_DECL_HIDDEN
  * Drop broken mid-button click handling (kde#383162)
  * KUndoActions: use actionCollection to set the shortcut
  * autotest: output filename on error
* Sat Aug 12 2017 christophe@krop.fr
- Update to 5.37.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.37.0.php
- Changes since 5.36.0 :
  * API dox: use official name "D-Bus"
  * API dox: fixes of typos & markup mistakes
  * Drop usage of KDE_DEFAULT_WINDOWFLAGS
  * API dox: fix another usage of KMainWindow in KXmlGuiWindow text
  * API dox: fix outdated note about KXmlGuiWindow constructor window flags arg
  * API dox: fix usage of KMainWindow in KXmlGuiWindow constructor text copy
* Wed Jul 12 2017 lbeltrame@kde.org
- Update to 5.36.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.36.0.php
- Changes since 5.35.0:
  * API dox: add notes to KActionCollection about QAction ownership handling
  * KKeySequenceWidget: make it possible to record Ctrl+Num+1 as a shortcut.
  * Revert "When building menu hyerarchies, parent menus to their containers"
  * Revert "use transientparent directly"
  * [FEATURE] Option to build & install QCH file with the public API dox
* Sun Jun 11 2017 lbeltrame@kde.org
- Update to 5.35.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.35.0.php
- Changes since 5.34.0:
  * Set main window as parent of stand-alone popup menus
  * API dox: Use doxygen notation to have comments used
  * API dox: note CamelCase includes by @class tag with more classes
  * use transientparent directly
  * When building menu hyerarchies, parent menus to their containers
* Mon May 15 2017 fabian@ritter-vogt.de
- Update to 5.34.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.34.0.php
- Changes since 5.33.0:
  * kcm_useraccount is dead, long live user_manager
  * Reproducible builds: drop version from XMLGUI_COMPILING_OS
  * Fix: DOCTYPE name must match root element type
  * Fix wrong usage of ANY in kpartgui.dtd
  * Use non-deprecated <gui> root element
  * API dox fixes: replace 0 with nullptr or remove where not applied
* Sat Apr 15 2017 lbeltrame@kde.org
- Update to 5.33.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.33.0.php
- Changes since 5.32.0:
  * Upgrade ECM and KF5 version requirements for 5.33.0 release.
  * Fix outdated usages of NULL in API dox/comments
  * Upgrade KF5 version to 5.33.0.
* Fri Apr  7 2017 wbauer@tmo.at
- Drop use-setFallbackSessionManagementEnabled-API-with-5.5.1.patch
  as we don't build against Qt 5.5.1 any more
* Sun Mar 19 2017 lbeltrame@kde.org
- Update to 5.32.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.32.0.php
- Changes since 5.31.0:
  * Commit translations from l10n-kf5
  * Upgrade ECM and KF5 version requirements for 5.32.0 release.
  * Upgrade KF5 version to 5.32.0.
  * Don't use KConfig keys with backslashes
* Thu Feb  9 2017 hrvoje.senjan@gmail.com
- Update to 5.31.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.31.0.php
* Sun Jan  8 2017 hrvoje.senjan@gmail.com
- Update to 5.30.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.30.0.php
* Sun Dec  4 2016 hrvoje.senjan@gmail.com
- Update to 5.29.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.29.0.php
* Sat Nov  5 2016 hrvoje.senjan@gmail.com
- Update to 5.28.0
  * Allow using new style connect in KActionCollection::addAction
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.28.0.php
* Sun Oct  2 2016 hrvoje.senjan@gmail.com
- Update to 5.27.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.27.0.php
* Tue Sep  6 2016 hrvoje.senjan@gmail.com
- Update to 5.26.0
  * Port to Donate standard action
  * Port away from deprecated authorizeKAction
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.26.0.php
* Sun Aug  7 2016 hrvoje.senjan@gmail.com
- Update to 5.25.0
  * Qt >= 5.5 is now required
  * Fix minimum size hint (cut-off text) (kde#312667)
  * [KToggleToolBarAction] Honor action/options_show_toolbar restriction
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.25.0.php
* Wed Jul  6 2016 hrvoje.senjan@gmail.com
- Update to 5.24.0
  * KXMLGui: Fix merge indices when removing xmlgui clients with
    actions in groups (kde#64754)
  * Don't warn about "file found in compat location" if it wasn't
    found at all
  * Add donate menu item to help menu of our apps
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.24.0.php
* Mon Jun  6 2016 hrvoje.senjan@gmail.com
- Update to 5.23.0
  * Right-clicking the menu bar of an application will now longer
    allow bypassing
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.23.0.php
* Sat May  7 2016 hrvoje.senjan@gmail.com
- Update to 5.22.0 (boo#980066)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.22.0.php
* Wed Apr  6 2016 alarrosa@suse.com
- Don't apply use-setFallbackSessionManagementEnabled-API-with-5.5.1.patch
  in SLE12 since Qt 5.5.1 in SLE12 is not patched to support the new
  session management API from 5.6.0 .
* Mon Apr  4 2016 hrvoje.senjan@gmail.com
- Update to 5.21.0 (boo#974793)
  * Fix editing toolbars loses plugged actions
  * Upgrade Qt version requirement to 5.4.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.21.0.php
* Sun Mar  6 2016 hrvoje.senjan@gmail.com
- Update to 5.20.0 (boo#970856)
  * Use non-native Language name as fallback
  * Fix session management broken since KF5 / Qt5
    (kde#354724, boo#955280)
  * Shortcut schemes: support globally installed schemes
  * Use Qt's qHash(QKeySequence) when building against Qt 5.6+
  * Shortcut schemes: fix bug where two KXMLGUIClients with the
    same name overwrite each other's scheme file
  * kxmlguiwindowtest: add shortcuts dialog, for testing the
    shortcut schemes editor
  * Shortcut schemes: improve usability by changing texts in GUI
  * Shortcut schemes: improve scheme list combo
    (automatic size, don't clear on unknown scheme)
  * Shortcut schemes: don't prepend the guiclient name
    to the filename
  * Shortcut schemes: create dir before trying to save
    a new shortcut scheme
  * Shortcut schemes: restore layout margin, it looks
    very cramped otherwise
  * Fix memory leak in KXmlGui startup hook
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.20.0.php
- Drop upstreamed fix-session-saving.patch
* Fri Feb 26 2016 wbauer@tmo.at
- Enable use-setFallbackSessionManagementEnabled-API-with-5.5.1.patch
  unconditionally, the updated libqt5-qtbase is in Tumbleweed now
* Mon Feb 22 2016 hrvoje.senjan@gmail.com
- Add and enable use-setFallbackSessionManagementEnabled-API-with-5.5.1.patch
  on 42.1 Leap only, for now (kde#354724, boo#955280)
* Wed Feb 17 2016 hrvoje.senjan@gmail.com
- Added fix-session-saving.patch (kde#354724, boo#955280)
* Sat Feb  6 2016 hrvoje.senjan@gmail.com
- Update to 5.19.0 (boo#967668)
  * Add option to disable KGlobalAccel at compilation time
  * Repair path to app shortcut scheme
  * Fix listing of shortcut files (wrong QDir usage)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.19.0.php
* Sat Jan  2 2016 hrvoje.senjan@gmail.com
- Update to 5.18.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.18.0.php
* Thu Dec 10 2015 hrvoje.senjan@gmail.com
- Update to 5.17.0
  * Don't call QCoreApplication::setQuitLockEnabled(true) on init.
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.17.0.php
* Sun Nov  8 2015 hrvoje.senjan@gmail.com
- Update to 5.16.0 (boo#955067)
  * kmainwindow: Pre-fill translator information when available.
    (kde#345320)
  * Allow to bind the contextmenu key (lower right) to shortcuts
    (kde#165542)
  * Add function to query standards xml file location
  * Allow kxmlgui framework to be used without any installed files
  * Add missing required dependencies
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.16.0.php
* Mon Oct  5 2015 hrvoje.senjan@gmail.com
- Update to 5.15.0
  * Make it possible to import/export shortcut schemes symmetrically
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.15.0.php
* Tue Sep  8 2015 hrvoje.senjan@gmail.com
- Update to 5.14.0
  * Fix KSwitchLanguageDialog not showing most languages
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.14.0.php
* Tue Aug  4 2015 hrvoje.senjan@gmail.com
- Update to 5.13.0
  * The Qt version requirement has been bumped from 5.2 to 5.3
  * Debug output has been ported to categorized output, for less
    noise by default
  * Docbook documentation has been reviewed and updated
  * Fix method behavior KShortcutsEditorPrivate::importConfiguration
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.13.0.php
* Sun Jul  5 2015 hrvoje.senjan@gmail.com
- Update to 5.12.0
  * Don't show "KDE Frameworks version" in the About KDE dialog
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.12.0.php
* Sun Jun  7 2015 hrvoje.senjan@gmail.com
- Update to 5.11.0
  * Add session management for KMainWindow (kde#346768)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.11.0.php
- Drop 0001-Add-session-management-for-KMainWindow.patch, merged upstream
* Tue May 12 2015 hrvoje.senjan@gmail.com
- Add 0001-Add-session-management-for-KMainWindow.patch (kde#346768)
* Sun May  3 2015 hrvoje.senjan@gmail.com
- Update to 5.10.0
  * Fix shortcuts when secondary shortcut set (kde#345411)
  * Update list of bugzilla products/components for bug reporting
    (kde#346559)
  * Global shortcuts: allow configuring also the alternate shortcut
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.10.0.php
* Sat Apr  4 2015 hrvoje.senjan@gmail.com
- Update to 5.9.0
  * Preserve translation domain when merging .rc files
  * Fix runtime warning QWidget::setWindowModified:
    The window title does not contain a '[*]' placeholder
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.9.0.php
- Drop no longer needed Requires of the devel subpackage:
  attica-qt5-devel, kglobalaccel-devel, ki18n-devel, kiconthemes-devel,
  kitemviews-devel, ktextwidgets-devel, kwidgetsaddons-devel and
  kwindowsystem-devel
* Sat Mar  7 2015 hrvoje.senjan@gmail.com
- Update to 5.8.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.8.0.php
* Sun Feb  8 2015 hrvoje.senjan@gmail.com
- Update to 5.7.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.7.0.php
* Sat Jan  3 2015 hrvoje.senjan@gmail.com
- Update to 5.6.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.6.0.php
* Sat Dec  6 2014 hrvoje.senjan@gmail.com
- Update to 5.5.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.5.0.php
* Sun Nov  2 2014 hrvoje.senjan@gmail.com
- Update to 5.4.0
  * Now supports finding ui files in resources
    (default location: :/kxmlgui5/<componentname>)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.4.0.php
* Sat Oct  4 2014 hrvoje.senjan@gmail.com
- Update to 5.3.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.3.0.php
* Sun Sep 21 2014 hrvoje.senjan@gmail.com
- Make KXMLLGui own %%{_kf5_sharedir}/kxmlgui5/
* Tue Sep  9 2014 hrvoje.senjan@gmail.com
- Update to 5.2.0
  * KXmlGui: KActionCollection::setDefaultShortcuts now makes the
    shortcut active too, to simplify application code.
  * For more details please see:
    http://kde.org/announcements/kde-frameworks-5.2.php
* Sat Aug  2 2014 hrvoje.senjan@gmail.com
- Update to 5.1.0
  * For more details please see:
    http://www.kde.org/announcements/kde-frameworks-5.1.php
* Fri Jul 11 2014 hrvoje.senjan@gmail.com
- Define kf5_version within package
* Tue Jul  1 2014 hrvoje.senjan@gmail.com
- Update to 5.0.0
  * Final release of KDE Frameworks 5
  * API improvements and cleanups
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/kde-frameworks-5.0.php
* Sun Jun  1 2014 hrvoje.senjan@gmail.com
- Update to 4.100.0
  * API improvements and cleanups
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/announce-frameworks5-beta3.php
- Add baselibs.conf
* Sun May  4 2014 hrvoje.senjan@gmail.com
- Update to 4.99.0
  * API improvements and cleanups
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/announce-frameworks5-beta2.php
* Sat Mar 29 2014 hrvoje.senjan@gmail.com
- Update to 4.98.0
  * API improvements and cleanups
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/announce-frameworks5-beta1.php
* Tue Mar  4 2014 hrvoje.senjan@gmail.com
- Update to 4.97.0:
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/announce-frameworks5-alpha2.php
* Thu Feb 27 2014 hrvoje.senjan@gmail.com
- Mark license as LGPL-2.1+ and GPL-2.0+ (ksendbugmail is GPL-2.0+)
* Sat Feb  8 2014 hrvoje.senjan@gmail.com
- Init kxmlgui package
